@@ -82,7 +82,7 @@ class CssParserLoadingTests < Minitest::Test
 
   def test_following_at_import_rules_local
     base_dir = File.expand_path('fixtures', __dir__)
-    @cp.load_file!('import1.css', base_dir)
+    @cp.load_file!('import1.css', base_dir: base_dir)
 
     # from '/import1.css'
     assert_equal 'color: lime;', @cp.find_by_selector('div').join(' ')
@@ -204,16 +204,4 @@ class CssParserLoadingTests < Minitest::Test
 
     cp_without_exceptions.load_uri!("#{@uri_base}/no-exist.xyz")
   end
-
-  def test_rule_set_argument_exceptions
-    cp_with_exceptions = Parser.new(rule_set_exceptions: true)
-
-    assert_raises ArgumentError, 'background-color value is empty' do
-      cp_with_exceptions.add_rule!('body', 'background-color: !important')
-    end
-
-    cp_without_exceptions = Parser.new(rule_set_exceptions: false)
-
-    cp_without_exceptions.add_rule!('body', 'background-color: !important')
-  end
 end
